Index: trunk/LMDZ.COMMON/ioipsl/install_ioipsl_centos-ifort.bash
===================================================================
--- trunk/LMDZ.COMMON/ioipsl/install_ioipsl_centos-ifort.bash	(revision 2183)
+++ trunk/LMDZ.COMMON/ioipsl/install_ioipsl_centos-ifort.bash	(revision 2185)
@@ -1,19 +1,10 @@
 #!/bin/bash
 # script to download and install the latest version of IOIPSL on Gnome
 #
 
 #0. Preliminary stuff 
-source ../arch.env
-
-####
-#source ../arch.path
-#marche pas car -I deja inclus
-#donc mettre en dur:
-####
-NETCDF="/opt/netcdf45/ifort15"
-netcdf_include="$NETCDF/include"
-netcdf_lib="$NETCDF/lib"
-echo $netcdf_include
-echo $netcdf_lib
+# source the environment from the GCM arch files
+source ../arch/arch-centos-ifort-para.env
+source ../arch/arch-centos-ifort-para.path
 
 whereami=`pwd -P`
@@ -27,5 +18,5 @@
 # 2. Set correct settings:
 # add a "ciclad" configuration to AA_make.gdef
-echo "#-Q- cicladi  #- Global definitions for ciclad at UPMC, ifort" >> AA_make.gdef
+echo "#-Q- cicladi  #- Global definitions for CentOS at LMD, ifort" >> AA_make.gdef
 echo "#-Q- cicladi  M_K = make" >> AA_make.gdef
 echo "#-Q- cicladi  P_C = cpp" >> AA_make.gdef
@@ -48,8 +39,6 @@
 echo "#-Q- cicladi  C_L = icc" >> AA_make.gdef
 echo "#-Q- cicladi  #-" >> AA_make.gdef
-echo "#-Q- cicladi  NCDF_INC = ${netcdf_include}" >> AA_make.gdef
-echo "#-Q- cicladi  NCDF_LIB = -L${netcdf_lib} -lnetcdff" >> AA_make.gdef
-#echo "#-Q- cicladi  NCDF_INC = ${NETCDF_INCDIR}" >> AA_make.gdef
-#echo "#-Q- cicladi  NCDF_LIB = -L${NETCDF_LIBDIR} -lnetcdff" >> AA_make.gdef
+echo "#-Q- cicladi  NCDF_INC = ${NETCDF_INCDIR:2}" >> AA_make.gdef
+echo "#-Q- cicladi  NCDF_LIB = ${NETCDF_LIBDIR} ${NETCDF_LIB}" >> AA_make.gdef
 echo "#-Q- cicladi  #-" >> AA_make.gdef
 
@@ -1,19 +1,10 @@
 #!/bin/bash
-# script to download and install the latest version of IOIPSL on Gnome
+# script to download and install the latest version of IOIPSL on LMD CentOS machines
 #
 
